<?php

/**
 * Main Ajax Controller
 *
 * @link 		https://lin3s.com
 * @since 		1.0.0
 *
 * @package 	Alexandria_Mail_Builder
 * @subpackage 	Alexandria_Mail_Builder/admin/controllers
 */

if( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// handle all ajax

function alexandria_mail_builder_ajax() {

	$action = empty($_POST['alexandria_mail_builder_action']) ? 'start' : $_POST['alexandria_mail_builder_action'];

	$lang = empty($_POST['lang']) ? 'es' : $_POST['lang'];
	
	switch($action) {
		// start mail builder
		case 'start':
		default:
		echo MainEmailBuilderController :: intiBuilder($lang);
		break;
	}

	exit;
}

/**
 * Get interlocutors situations
 *
 * @since 		1.0.0
 *
 */
function alexandria_email_builder_get_interlocutor_situations_ajax() {

	global $sitepress;

	// lang from your javascript
	$lang = empty($_POST['lang']) ? 'es' : $_POST['lang'];

	// switch to the desired language
	$sitepress->switch_lang($lang);

	$interlocutor_id = empty($_POST['interlocutor_id']) ? '' : $_POST['interlocutor_id'];

	$data = [
		'situations_email_categories' => []
	];

	if(empty($_POST['interlocutor_id'])) {
		echo json_encode($data);
		exit;
	}

	$args = array(  
		'post_type' => 'emails',
		'post_status' => 'publish',
		'numberposts' => -1,
		'suppress_filters' => 0,
		'distinct' => false,
		'meta_query' => array(
			array(
				'key'   => '_interlocutor_email',
				'value' => intval($interlocutor_id),
				'meta_compare'	=> '='
			)
		)
	);

	$emails = get_posts($args);

	foreach ($emails as $key => $email) {

		$situation_id = get_post_meta( $email->ID, '_situation_email', true );
		$term = [];

		$situation = get_post($situation_id);
		$terms = get_the_terms($situation_id, 'situations-email-categories');
		$term = array_pop($terms);

		$data['situations_email_categories'][$key] = $situation;
		$data['situations_email_categories'][$key]->category = $term;

	}
	
	echo json_encode($data);
	exit;
}

/**
 * Get interlocutors tonos
 *
 * @since 		1.0.0
 *
 */
function alexandria_email_builder_get_interlocutor_tonos_ajax() {

	global $sitepress;

	// lang from your javascript
	$lang = empty($_POST['lang']) ? 'es' : $_POST['lang'];

	// switch to the desired language
	$sitepress->switch_lang($lang);

	$interlocutor_id = empty($_POST['interlocutor_id']) ? '' : $_POST['interlocutor_id'];
	$situation_id = empty($_POST['situation_id']) ? '' : $_POST['situation_id'];

	$data = [
		'tonos' => []
	];

	if(empty($_POST['interlocutor_id']) || empty($_POST['situation_id'])) {
		echo json_encode($data);
		exit;
	}

	$args = array(  
		'post_type' => 'emails',
		'post_status' => 'publish',
		'numberposts' => -1,
		'suppress_filters' => 0,
		'distinct' => false,
		'meta_query' => array(
			'relation' => 'AND',
			array(
				'key'   => '_interlocutor_email',
				'value' => intval($interlocutor_id),
				'meta_compare'	=> '='
			),
			array(
				'key'   => '_situation_email',
				'value' => intval($situation_id),
				'meta_compare'	=> '='
			)
		)
	);

	$emails = get_posts($args);

	foreach ($emails as $key => $email) {

		$tono_id = get_post_meta( $email->ID, '_tono_email', true );
		$tono = get_post($tono_id);

		$data['tonos'][$key] = $tono;
		$data['tonos'][$key]->background_color = get_post_meta( $tono_id, 'background_color', true );
		$data['tonos'][$key]->text_color = get_post_meta( $tono_id, 'text_color', true );
		$data['tonos'][$key]->border_color = get_post_meta( $tono_id, 'border_color', true );
	}
	
	echo json_encode($data);
	exit;
}

function alexandria_email_builder_get_custom_post_metadata_ajax() {

	$action = empty($_POST['alexandria_email_builder_get_custom_post_metadata_ajax']) ? 'metadata' : $_POST['alexandria_email_builder_get_custom_post_metadata_ajax'];

	$lang = empty($_POST['lang']) ? 'es' : $_POST['lang'];
	
	switch($action) {
		// get post metadata
		case 'metadata':
		default:
		echo MainEmailBuilderController :: getMailMetadata($lang);
		break;
	}

	exit;
}

function alexandria_email_builder_process_contact_form() {

	$full_name = $_POST['full_name'];
	$email = $_POST['email'];
	$message = $_POST['message'];

	$template = get_option( 'message_mail' ) ? get_option('message_mail') : '';

 	$template = str_replace("{{full_name}}", $full_name, $template);
 	$template = str_replace("{{email}}", $email, $template);
 	$template = str_replace("{{message}}", $message, $template);

	$to = 'test@entusiastics.com';
	$subject = get_option('subject_mail') ? get_option('subject_mail') : '';
	$body = $text;

	$headers = array('Content-Type: text/html; charset=UTF-8');

	wp_mail( $to, $subject, $body, $headers );

	exit;
	
}

function alexandria_email_builder_order_list_cpt_ajax() {

	parse_str($_POST['order'], $data);

	if (!is_array($data))
		return false;

	$id_arr = array();
	foreach ($data as $key => $values) {
		foreach ($values as $position => $id) {
			$id_arr[] = $id;
		}
	}

	$menu_order_arr = array();

	foreach ($id_arr as $key => $id) {

		$order = get_post_meta( $id, 'order', true );
		$menu_order_arr[] = $order;
		
	}

	sort($menu_order_arr);

	foreach ($data as $key => $values) {

		foreach ($values as $position => $id) {

			update_post_meta(intval($id), 'order', intval($menu_order_arr[$position]));

		}
	}

	exit;
	
}

