<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * Dashboard. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @author 				lin3s
 * @link 				https://lin3s.com
 * @since 				1.0.0
 * @package 			Alexandria_Mail_Builder
 *
 * @wordpress-plugin
 * Plugin Name: 		Mail Builder
 * Plugin URI: 			https://lin3s.com
 * Description: 		Construye tu email
 * Version: 			1.3.0
 * Author: 				lin3s
 * Author URI: 			https://lin3s.com/
 * License: 			GPL-2.0+
 * License URI: 		http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: 		alexandria-mail-builder
 * Domain Path: 		/languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

// Used for referring to the plugin file or basename
if ( ! defined( 'ALEXANDRIA_MAIL_BUILDER_FILE' ) ) {
	define( 'ALEXANDRIA_MAIL_BUILDER_FILE', plugin_basename( __FILE__ ) );
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/alexandria-mail-builder-activator.php
 */
function activate_Alexandria_Mail_Builder() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/alexandria-mail-builder-activator.php';
	Alexandria_Mail_Builder_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/alexandria-mail-builder-deactivator.php
 */
function deactivate_Alexandria_Mail_Builder() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/alexandria-mail-builder-deactivator.php';
	Alexandria_Mail_Builder_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_Alexandria_Mail_Builder' );
register_deactivation_hook( __FILE__, 'deactivate_Alexandria_Mail_Builder' );

/**
 * The core plugin class that is used to define internationalization,
 * dashboard-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/alexandria-mail-builder.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since 		1.0.0
 */
function run_Alexandria_Mail_Builder() {

	$plugin = new Alexandria_Mail_Builder();
	$plugin->run();

}
run_Alexandria_Mail_Builder();