<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://lin3s.com
 * @since      1.0.0
 *
 * @package    Alexandria_Mail_Builder
 * @subpackage Alexandria_Mail_Builder/public
 */

class Alexandria_Mail_Builder_Template_Functions {

	/**
	 * Private static reference to this class
	 * Useful for removing actions declared here.
	 *
	 * @var 	object 		$_this
 	 */
	private static $_this;

	/**
	 * The post meta data
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$meta    			The post meta data.
	 */
	private $meta;

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version 			The version of this plugin.
	 */
	public function __construct($plugin_name, $version) {

		self::$_this = $this;

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	} // __construct()

	/**
	 * Includes the mail builder main template
	 *
	 * @hooked 		alexandria-mail-builder-loop-content 		10
	 *
	 * @param 		string 		$name 		A Template Name
	 * @param 		array 		$args 		Params passed to Template
	 */
	public function alexandria_mail_builder_template($name) {

		include alexandria_mail_builder_get_template($name);

	} // alexandria_mail_builder_template()

	/**
	 * Includes the mail builder main template
	 *
	 * @hooked 		alexandria-mail-builder-loop-content 		10
	 *
	 * @param 		string 		$name 		A Template Name
	 * @param 		array 		$args 		Params passed to Template
	 */
	public function alexandria_mail_builder_main_template($name, $args) {

		include alexandria_mail_builder_get_template($name);

	} // alexandria_mail_builder_main_template()

	/**
	 * Includes the not found mail builders template
	 *
	 * @hooked 		alexandria-mail-builder-loop-content 		15
	 *
	 * @param 		name 		$name 		A Template Name
	 * @param 		array 		$args 		Params passed to Template
	 */
	public function alexandria_email_not_found_template($name, $args) {

		include alexandria_mail_builder_get_template($name);

	} // alexandria_not_found_template()


	/**
	 * Returns a reference to this class. Used for removing
	 * actions and/or filters declared using an object of this class.
	 *
	 * @see  	http://hardcorewp.com/2012/enabling-action-and-filter-hook-removal-from-class-based-wordpress-plugins/
	 * @return 	object 		This class
	 */
	static function this() {

		return self::$_this;

	} // this()

} // class